@@ -10,7 +10,7 @@
 # ABSTRACT: Check the configuration of an application
 
 package App::Cme::Command::check ;
-$App::Cme::Command::check::VERSION = '1.012';
+$App::Cme::Command::check::VERSION = '1.014';
 use strict;
 use warnings;
 use 5.10.1;
@@ -52,13 +52,16 @@ sub execute {
     say "loading data" unless $opt->{quiet};
     Config::Model::ObjTreeScanner->new( leaf_cb => sub { } )->scan_node( undef, $root );
     say "checking data" unless $opt->{quiet};
-    $root->dump_tree( mode => 'full' );
+    $root->dump_tree( mode => 'full' ); # light check (value per value)
+    $root->deep_check; # consistency check
     say "check done" unless $opt->{quiet};
 
     my $ouch = $inst->has_warning;
 
-    if ( $opt->{strict} and $ouch ) {
-        die "Found $ouch warnings in strict mode\n";
+    if ( $ouch ) {
+        my $app = $inst->application;
+        warn "you can try 'cme fix $app' to fix the warnings shown above\n";
+        die "Found $ouch warnings in strict mode\n" if $opt->{strict};
     }
 }
 
@@ -76,7 +79,7 @@ App::Cme::Command::check - Check the configuration of an application
 
 =head1 VERSION
 
-version 1.012
+version 1.014
 
 =head1 SYNOPSIS
 
@@ -115,7 +118,8 @@ See L<cme/"Global Options">.
 
 =item -strict
 
-When set, cme will exit 1 if warnings are found during check (of left after fix)
+When set, cme exits 1 if warnings are found. By default, C<cme> exits
+0 when warnings are found.
 
 =back
 
@@ -123,7 +127,7 @@ When set, cme will exit 1 if warnings are found during check (of left after fix)
 
 cme exits 0 when no errors are found. Exit 1 otherwise.
 
-If C<-strict> option is set, cme will exit 1 when warnings are still present when the program ends.
+If C<-strict> option is set, cme exits 1 when warnings are found.
 
 =head1 SEE ALSO
 
