@@ -10,12 +10,12 @@
 #ABSTRACT: Common methods for App::Cme
 
 package App::Cme::Common;
-$App::Cme::Common::VERSION = '1.012';
+$App::Cme::Common::VERSION = '1.014';
 use strict;
 use warnings;
 use 5.10.1;
 
-use Config::Model 2.077;
+use Config::Model 2.089;
 use Config::Model::Lister;
 use Pod::POM;
 use Pod::POM::View::Text;
@@ -35,7 +35,7 @@ sub cme_global_options {
       [ "root-dir=s"         => "Change root directory. Mostly used for test"],
       [ "file=s"             => "Specify a target file"],
       [ "backend=s"          => "Specify a read/write backend"],
-      [ "stack-trace|trace!" => "Provides a full stack trace when exiting on error"],
+      [ "trace|stack-trace!" => "Provides a full stack trace when exiting on error"],
       [ "quiet!"             => "Suppress progress messages" ],
       # no bundling
       { getopt_conf => [ qw/no_bundling/ ] }
@@ -58,7 +58,10 @@ sub process_args {
     Config::Model::Exception::Any->Trace(1) if $opt->{trace};
 
     if ( not defined $root_model ) {
-        die "Unknown application: $application. Run 'cme list' to list available applications\n";
+        die "Can't locate model for application '$application'.\n"
+            . "Run 'cme list' for the list of models available on your system.\n"
+            . "You may need to install another Config::Model Perl module.\n"
+            . "See the available models there: https://github.com/dod38fr/config-model/wiki/Available-models-and-backends\n";
     }
 
     say "cme: using $root_model model" unless $opt->{quiet};
@@ -221,7 +224,7 @@ App::Cme::Common - Common methods for App::Cme
 
 =head1 VERSION
 
-version 1.012
+version 1.014
 
 =head1 SYNOPSIS
 
